==> aroundme_0_5_0.tar.tgz: aroundme_0_5_0/aroundme/template/barnraiser_01/search.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<form action="search.php" method="post">

<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="560" valign="top">
			<div class="box_top">
				<?php echo $lang['section_search'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td>
						<?php echo $lang['txt_search_basic_intro'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<div class="box_edit">
						<table cellpadding="2" cellspacing="0" border="0" width="100%">
							<tr>
								<td>
									<table cellpadding="4" cellspacing="0" border="0">
										<tr>
											<td>
												<input type="text" name="search_text" size="20" value="<?php if (isset($search_text)) { echo $search_text;};?>" /><br />
											</td>
											<td>
												<input type="image" src="<?php echo $templatePath;?>img/search.png" value="search" class="checkbox" /><br />
											</td>
										</tr>
									</table>
								</td>
							</tr>
						</table>
						</div>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<?php
			if (isset($search_text)) {
			?>
			<table width="100%" cellpadding="0" cellspacing="4" border="0">
				<tr>
					<td>
						<?php echo $lang['txt_search_results'];?><br />
					</td>
				</tr>
			</table>
			<?php }?>



			<?php
			if (isset($blogs)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_blogs'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['blog_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($subjects)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_subjects'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['subject_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($groups)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_groups'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($groups as $key => $i):
				?>
				<tr>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
									<span class="txt_footer">
									<?php echo $i['group_synopsis'];?><br />
									</span>
								</td>
								<td nowrap="nowrap" align="right">
									<?php echo $lang['txt_recommended_age'];?>:
									<?
									if ($i['group_from_age'] && $i['group_to_age']) {
									    echo $i['group_from_age'] . "/" . $i['group_to_age'];
									}
									else if ($i['group_from_age'] && !$i['group_to_age']) {
										echo $lang['txt_age_from'] . " " . $i['group_from_age'];
									}
									else if (!$i['group_from_age'] && $i['group_to_age']) {
										echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
									}
									else {
										echo $lang['txt_age_all'];
									}
									?><br />
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($polls)) {
 			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_polls'];?><br />
			</span>
			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<?php
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						$poll = $i;
						$poll_url = "mag_item.php?poll_id=" . $i['poll_id'];
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
 				?>
 			</table>
			<?php }?>


			<?php
			if (isset($library_items)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_library_items'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($library_items as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['library_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($tasks)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_tasks'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($tasks as $key => $i):
				?>
			     <tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td valign="top">
						<a href="a_activity.php?activity_id=<?php echo $i['activity_id'];?>"><?php echo $i['task_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['task_synopsis'];?></span><br />
					</td>
					<td align="right" valign="top" nowrap="nowrap">
						<?php echo $i['task_start_datetime'];?><br />
						<?php echo $i['task_user_requirement'];?><br />
					</td>
			    </tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>



			<?php
			if (isset($activities)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_activities'];?><br />
			</span>
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<?php
				foreach($activities as $key => $i):
				?>
			     <tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<a href="a_activity.php?activity_id=<?php echo $i['activity_id'];?>"><?php echo $i['activity_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['activity_synopsis'];?></span><br />
					</td>
					<td align="right" valign="top">
						<?php echo $i['display_activity_start_datetime'];?><br />
					</td>
			    </tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>

			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td>
						<div class="box_edit">
							<?php
							if (isset($users)) {
							?>
							<table border="0" width="100%" cellspacing="0" cellpadding="4">
								<tr>
									<td valign="top">
										<?php
											foreach ($users as $key => $i) :
										?>
												<a href="msg_compose.php?to_user_id=<?php echo $i['user_id']?>"><?php echo $i['profile_nic']?></a><br />
										<?php
											endforeach;
										?>
									</td>
								</tr>
							</table>
							<?php }?>
			</div>
						friends
						language
						rsp type
					</td>
				</tr>
			</table>

			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_5_1.tar.tgz: aroundme_0_5_1/aroundme/template/barnraiser_01/search.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<form action="search.php" method="post">

<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="560" valign="top">
			<div class="box_top">
				<?php echo $lang['section_search'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td>
						<?php echo $lang['txt_search_basic_intro'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<div class="box_edit">
						<table cellpadding="2" cellspacing="0" border="0" width="100%">
							<tr>
								<td>
									<table cellpadding="4" cellspacing="0" border="0">
										<tr>
											<td>
												<input type="text" name="search_text" size="20" value="<?php if (isset($search_text)) { echo $search_text;};?>" /><br />
											</td>
											<td>
												<input type="image" src="<?php echo $templatePath;?>img/search.png" value="search" class="checkbox" /><br />
											</td>
										</tr>
									</table>
								</td>
							</tr>
						</table>
						</div>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<?php
			if (isset($search_text)) {
			?>
			<table width="100%" cellpadding="0" cellspacing="4" border="0">
				<tr>
					<td>
						<?php echo $lang['txt_search_results'];?><br />
					</td>
				</tr>
			</table>
			<?php }?>



			<?php
			if (isset($blogs)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_blogs'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['blog_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($subjects)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_subjects'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['subject_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($groups)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_groups'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($groups as $key => $i):
				?>
				<tr>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
									<span class="txt_footer">
									<?php echo $i['group_synopsis'];?><br />
									</span>
								</td>
								<td nowrap="nowrap" align="right">
									<?php echo $lang['txt_recommended_age'];?>:
									<?
									if ($i['group_from_age'] && $i['group_to_age']) {
									    echo $i['group_from_age'] . "/" . $i['group_to_age'];
									}
									else if ($i['group_from_age'] && !$i['group_to_age']) {
										echo $lang['txt_age_from'] . " " . $i['group_from_age'];
									}
									else if (!$i['group_from_age'] && $i['group_to_age']) {
										echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
									}
									else {
										echo $lang['txt_age_all'];
									}
									?><br />
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($polls)) {
 			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_polls'];?><br />
			</span>
			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<?php
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						$poll = $i;
						$poll_url = "mag_item.php?poll_id=" . $i['poll_id'];
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
 				?>
 			</table>
			<?php }?>


			<?php
			if (isset($library_items)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_library_items'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($library_items as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['library_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($tasks)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_tasks'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($tasks as $key => $i):
				?>
			     <tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td valign="top">
						<a href="sch_item.php?schedule_id=<?php echo $i['schedule_id'];?>"><?php echo $i['schedule_title'];?></a><br />
						<?php echo $i['schedule_synopsis'];?><br />
					</td>
					<td align="right" valign="top" nowrap="nowrap">
						<?php echo $i['display_schedule_start_datetime'];?><br />
						<?php echo $i['schedule_allocation'];?><br />
					</td>
			    </tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>



			<?php
			if (isset($activities)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_activities'];?><br />
			</span>
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<?php
				foreach($activities as $key => $i):
				?>
			     <tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<a href="sch_item.php?schedule_id=<?php echo $i['schedule_id'];?>"><?php echo $i['schedule_title'];?></a><br />
						<?php echo $i['schedule_synopsis'];?><br />
					</td>
					<td align="right" valign="top">
						<?php echo $i['display_schedule_start_datetime'];?><br />
					</td>
			    </tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>

			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td>
						<div class="box_edit">
							<?php
							if (isset($users)) {
							?>
							<table border="0" width="100%" cellspacing="0" cellpadding="4">
								<tr>
									<td valign="top">
										<?php
											foreach ($users as $key => $i) :
										?>
												<a href="msg_compose.php?to_user_id=<?php echo $i['user_id']?>"><?php echo $i['profile_nic']?></a><br />
										<?php
											endforeach;
										?>
									</td>
								</tr>
							</table>
							<?php }?>
							</div>
					</td>
				</tr>
			</table>

			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
</form>
